about summary refs log tree commit diff
path: root/sysdeps/unix/sysv/linux/bits/socket.h
diff options
context:
space:
mode:
authorUlrich Drepper <drepper@gmail.com>2011-05-28 01:43:20 -0400
committerUlrich Drepper <drepper@gmail.com>2011-05-28 01:43:20 -0400
commitf1f929d74a08d6f973cec20e311401586f408d35 (patch)
treeaad431c8f39d6474212303226cc49dd2a642d99b /sysdeps/unix/sysv/linux/bits/socket.h
parentce67228d570d2df88d74184e5e3618a5b2ef8704 (diff)
downloadglibc-f1f929d74a08d6f973cec20e311401586f408d35.tar.gz
glibc-f1f929d74a08d6f973cec20e311401586f408d35.tar.xz
glibc-f1f929d74a08d6f973cec20e311401586f408d35.zip
Add sendmmsg syscall
Diffstat (limited to 'sysdeps/unix/sysv/linux/bits/socket.h')
-rw-r--r--sysdeps/unix/sysv/linux/bits/socket.h9
1 files changed, 8 insertions, 1 deletions
diff --git a/sysdeps/unix/sysv/linux/bits/socket.h b/sysdeps/unix/sysv/linux/bits/socket.h
index 637375791d..96d9fed034 100644
--- a/sysdeps/unix/sysv/linux/bits/socket.h
+++ b/sysdeps/unix/sysv/linux/bits/socket.h
@@ -421,7 +421,7 @@ struct linger
 
 __BEGIN_DECLS
 
 /* Receive a message as described by MESSAGE from socket FD.
    Returns the number of bytes read or -1 for errors.
 
    This function is a cancellation point and therefore not marked with
@@ -430,6 +430,13 @@ extern int recvmmsg (int __fd, struct mmsghdr *__vmessages,
 		     unsigned int __vlen, int __flags,
 		     __const struct timespec *__tmo);
 
+/* Send a VLEN messages as described by VMESSAGES to socket FD.
+   Return the number of datagrams successfully written or -1 for errors.
+This function is a cancellation point and therefore not marked with
+   __THROW.  */
+extern int sendmmsg (int __fd, struct mmsghdr *__vmessages,
+		     unsigned int __vlen, int __flags);
+
 __END_DECLS
 
 #endif	/* bits/socket.h */
@@ -421,7 +421,7 @@ struct linger
 __BEGIN_DECLS
 
-/* Receive a message as described by MESSAGE from socket FD.
+/* Receive up to VLEN messages as described by VMESSAGES from socket FD.
    Returns the number of bytes read or -1 for errors.
 